summaryrefslogtreecommitdiffstats
path: root/kbarcode/barcodecombo.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kbarcode/barcodecombo.cpp')
-rw-r--r--kbarcode/barcodecombo.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/kbarcode/barcodecombo.cpp b/kbarcode/barcodecombo.cpp
index 5393a8f..e1e9dd8 100644
--- a/kbarcode/barcodecombo.cpp
+++ b/kbarcode/barcodecombo.cpp
@@ -122,8 +122,8 @@ BarcodeWidget::BarcodeWidget(TQWidget *parent, const char *name )
grid->addWidget( labelStandard, 1, 0 );
comboStandard = new BarcodeCombo( this, "comboStandard" );
- connect( comboStandard, TQT_SIGNAL( activated(int) ), this, TQT_SLOT( encodingChanged() ) );
- connect( comboStandard, TQT_SIGNAL( activated(int) ), this, TQT_SLOT( changed() ) );
+ connect( comboStandard, TQ_SIGNAL( activated(int) ), this, TQ_SLOT( encodingChanged() ) );
+ connect( comboStandard, TQ_SIGNAL( activated(int) ), this, TQ_SLOT( changed() ) );
grid->addMultiCellWidget( comboStandard, 1, 1, 1, 3 );
labelStandard->setBuddy( comboStandard );
@@ -133,8 +133,8 @@ BarcodeWidget::BarcodeWidget(TQWidget *parent, const char *name )
data = new KLineEdit( this, "data" );
labelData->setBuddy( data );
- connect( data, TQT_SIGNAL( textChanged( const TQString & ) ), this, TQT_SLOT( changed() ) );
- connect( data, TQT_SIGNAL( textChanged( const TQString & ) ), this, TQT_SLOT( slotValidateValue() ) );
+ connect( data, TQ_SIGNAL( textChanged( const TQString & ) ), this, TQ_SLOT( changed() ) );
+ connect( data, TQ_SIGNAL( textChanged( const TQString & ) ), this, TQ_SLOT( slotValidateValue() ) );
grid->addMultiCellWidget( data, 2, 2, 1, 3 );
multi = new KTextEdit( this );
@@ -145,13 +145,13 @@ BarcodeWidget::BarcodeWidget(TQWidget *parent, const char *name )
multi->setVScrollBarMode( TQScrollView::AlwaysOn );
multi->setHScrollBarMode( TQScrollView::AlwaysOn );
multi->hide();
- connect( multi, TQT_SIGNAL( textChanged() ), this, TQT_SLOT( changed() ) );
+ connect( multi, TQ_SIGNAL( textChanged() ), this, TQ_SLOT( changed() ) );
grid->addMultiCellWidget( multi, 3, 3, 1, 3 );
checkText = new TQCheckBox( this, "checkText" );
checkText->setText( i18n( "&Display text" ) );
checkText->setChecked( true );
- connect( checkText, TQT_SIGNAL( clicked() ), this, TQT_SLOT( changed() ) );
+ connect( checkText, TQ_SIGNAL( clicked() ), this, TQ_SLOT( changed() ) );
grid->addWidget( checkText, 4, 1 );
buttonAdvanced = new KPushButton( i18n("&Advanced..."), this );
@@ -166,31 +166,31 @@ BarcodeWidget::BarcodeWidget(TQWidget *parent, const char *name )
spinMargin->setLabel( i18n( "&Margin:" ), KNumInput::AlignLeft | KNumInput::AlignVCenter );
spinMargin->setRange( 0, 10000, 1, false );
spinMargin->setValue( 10 );
- connect( spinMargin, TQT_SIGNAL( valueChanged(int) ), this, TQT_SLOT( changed() ) );
+ connect( spinMargin, TQ_SIGNAL( valueChanged(int) ), this, TQ_SLOT( changed() ) );
grid->addMultiCellWidget( spinMargin, 5, 5, 0, 1 );
spinRotation = new KIntNumInput( this );
spinRotation->setLabel( i18n( "&Rotation:" ), KNumInput::AlignLeft | KNumInput::AlignVCenter );
spinRotation->setRange( 0, 360, 90, false );
spinRotation->setValue( 0 );
- connect( spinRotation, TQT_SIGNAL( valueChanged(int) ), this, TQT_SLOT( changed() ) );
+ connect( spinRotation, TQ_SIGNAL( valueChanged(int) ), this, TQ_SLOT( changed() ) );
grid->addMultiCellWidget( spinRotation, 5, 5, 2, 3 );
spinScale = new KIntNumInput( spinMargin, 1000, this );
spinScale->setLabel( i18n("&Scale (in permille):"), KNumInput::AlignLeft | KNumInput::AlignVCenter );
spinScale->setRange( 100, 10000, 100, false );
spinScale->setValue( 1000 );
- connect( spinScale, TQT_SIGNAL( valueChanged(int) ), this, TQT_SLOT( changed() ) );
+ connect( spinScale, TQ_SIGNAL( valueChanged(int) ), this, TQ_SLOT( changed() ) );
grid->addMultiCellWidget( spinScale, 6, 6, 0, 1 );
spinCut = new KIntNumInput( spinRotation, 100, this );
spinCut->setLabel( i18n("&Crop:"), KNumInput::AlignLeft | KNumInput::AlignVCenter );
spinCut->setRange( 1, 100, 1, false );
- connect( spinCut, TQT_SIGNAL( valueChanged(int) ), this, TQT_SLOT( changed() ) );
+ connect( spinCut, TQ_SIGNAL( valueChanged(int) ), this, TQ_SLOT( changed() ) );
grid->addMultiCellWidget( spinCut, 6, 6, 2, 3 );
- connect( buttonAdvanced, TQT_SIGNAL( clicked() ), this, TQT_SLOT( advanced() ) );
- connect( buttonToken, TQT_SIGNAL( clicked() ), this, TQT_SLOT( tokens() ) );
+ connect( buttonAdvanced, TQ_SIGNAL( clicked() ), this, TQ_SLOT( advanced() ) );
+ connect( buttonToken, TQ_SIGNAL( clicked() ), this, TQ_SLOT( tokens() ) );
m_enabledata = true;
m_multi = false;
@@ -200,7 +200,7 @@ BarcodeWidget::BarcodeWidget(TQWidget *parent, const char *name )
void BarcodeWidget::getData( Barkode & barcode )
{
// make sure all changes are applied to the barcode
// even if not all widgets have emitted their changed TQT_SIGNAL yet
this->changed();
barcode = m_barcode;
@@ -200,7 +200,7 @@ BarcodeWidget::BarcodeWidget(TQWidget *parent, const char *name )
{
// make sure all changes are applied to the barcode
- // even if not all widgets have emitted their changed TQT_SIGNAL yet
+ // even if not all widgets have emitted their changed TQ_SIGNAL yet
this->changed();
barcode = m_barcode;